@@ -17,18 +17,18 @@ import logging
 
 from .args import argparse
 from .client import Client
-from .repo import sync
 from .logger import setup_logger
+from .repo import sync
 
 
 def main():
     ns = argparse()
-    setup_logger(verbose=ns.verbose)
+    setup_logger(verbose=ns.verbose, quiet=ns.quiet)
 
     logger = logging.getLogger('gstore.cli')
 
     try:
-        client = Client(ns.token)
+        client = Client(token=ns.token, api_host=ns.host)
 
         if ns.org is None:
             orgs = client.get_orgs()
