@@ -16,33 +16,41 @@
 import logging
 
 from github import Github
-from gstore import __version__
 
+from gstore import __version__
 
 USER_AGENT = 'Gstore/{}'.format(__version__)
 
-DEFAULT_BASE_URL = 'https://api.github.com'
+DEFAULT_HOST = 'api.github.com'
 DEFAULT_TIMEOUT = 15
 
+TOKEN_NAMES = (
+    'GH_TOKEN',
+    'GITHUB_TOKEN',
+    'GH_ENTERPRISE_TOKEN',
+    'GITHUB_ENTERPRISE_TOKEN',
+)
+
 
 class Client:
     def __init__(
             self,
             token: str,
-            api_url=DEFAULT_BASE_URL,
+            api_host=DEFAULT_HOST,
             timeout=DEFAULT_TIMEOUT,
     ):
         """
         :param str token: Authentication token for github.com API requests
-        :param str api_url: Default base URL for github.com API requests
+        :param str api_host: Default base URL for github.com API requests
         :param int timeout: Timeout for HTTP requests
-        :param str user_agent: Default user agent to make HTTP requests
         """
 
         if not token:
             raise ValueError(
                 'GitHub token was not provided but it is mandatory')
 
+        api_url = 'https://{}'.format(api_host)
+
         self.github = Github(
             login_or_token=token,
             base_url=api_url,
